@@ -3,7 +3,12 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-"""Functions for generating random numbers."""
+"""
+`adafruit_rsa.randnum`
+====================================================
+
+Functions for generating random numbers.
+"""
 
 # Source inspired by code by Yesudeep Mangalapilly <yesudeep@gmail.com>
 
@@ -16,7 +21,7 @@ __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_RSA.git"
 
 
-def read_random_bits(nbits):
+def read_random_bits(nbits: int) -> bytes:
     """Reads 'nbits' random bits.
 
     If nbits isn't a whole number of bytes, an extra byte will be appended with
@@ -37,7 +42,7 @@ def read_random_bits(nbits):
     return randomdata
 
 
-def read_random_int(nbits):
+def read_random_int(nbits: int) -> int:
     """Reads a random integer of approximately nbits bits."""
 
     randomdata = read_random_bits(nbits)
@@ -50,7 +55,7 @@ def read_random_int(nbits):
     return value
 
 
-def read_random_odd_int(nbits):
+def read_random_odd_int(nbits: int) -> int:
     """Reads a random odd integer of approximately nbits bits.
 
     >>> read_random_odd_int(512) & 1
@@ -63,7 +68,7 @@ def read_random_odd_int(nbits):
     return value | 1
 
 
-def randint(maxvalue):
+def randint(maxvalue: int) -> int:
     """Returns a random integer x with 1 <= x <= maxvalue
 
     May take a very long time in specific situations. If maxvalue needs N bits
